netapp_ontap.models.data_engine_datacollection_acl_user_or_group API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_datacollection_acl_user_or_group`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineDatacollectionAclUserOrGroupSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineDatacollectionAclUserOrGroup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `allocation_time: ImpreciseDateTime GET`

    The time when the user or group is granted access to the data collection.

    Example: 2025-06-04T19:00:00.000+0000

  `name: str GET POST PATCH`

    Name of the user or group.

    Example: user1